@@ -1,5 +1,6 @@
 """ Unit tests for XSD hash function
 """
+
 from os.path import join, dirname, abspath
 from unittest import TestCase
 
@@ -9,7 +10,11 @@ RESOURCES_PATH = join(dirname(abspath(__file__)), "data")
 
 
 class TestSimpleXSD(TestCase):
+    """Test Simple XSD"""
+
     def setUp(self):
+        """setUp"""
+
         with open(
             join(RESOURCES_PATH, "chemical-element.xsd"), "r", encoding="utf-8"
         ) as xsd_file:
@@ -17,6 +22,8 @@ class TestSimpleXSD(TestCase):
             self.hash = xsd_hash.get_hash(self.content)
 
     def test_same_file(self):
+        """test_same_file"""
+
         # Make sure that the same XSD produces the same hash
         with open(
             join(RESOURCES_PATH, "chemical-element.xsd"), "r", encoding="utf-8"
@@ -27,6 +34,8 @@ class TestSimpleXSD(TestCase):
         self.assertEqual(self.hash, content_hash)
 
     def test_different_spaces_01(self):
+        """test_different_spaces_01"""
+
         # Make sure that an XSD with additional spaces produces the same hash
         with open(
             join(RESOURCES_PATH, "chemical-element-spaces-01.xsd"),
@@ -39,6 +48,8 @@ class TestSimpleXSD(TestCase):
         self.assertEqual(self.hash, content_hash)
 
     def test_different_spaces_02(self):
+        """test_different_spaces_02"""
+
         # Make sure that an XSD with additional spaces, returns,tabs produces
         # the same hash
         with open(
@@ -52,6 +63,8 @@ class TestSimpleXSD(TestCase):
         self.assertEqual(self.hash, content_hash)
 
     def test_different_documentation(self):
+        """test_different_documentation"""
+
         # Make sure that an XSD with documentation tags produces different hash
         with open(
             join(RESOURCES_PATH, "chemical-element-documentation.xsd"),
@@ -63,24 +76,34 @@ class TestSimpleXSD(TestCase):
         self.assertEqual(self.hash, content_hash)
 
     def test_different_annotations_01(self):
+        """test_different_annotations_01"""
+
         # Make sure that an XSD with different comments produces the same hash
         with open(
-            join(RESOURCES_PATH, "chemical-element-annot-01.xsd"), "r", encoding="utf-8"
+            join(RESOURCES_PATH, "chemical-element-annot-01.xsd"),
+            "r",
+            encoding="utf-8",
         ) as xsd_file:
             content = xsd_file.read()
             content_hash = xsd_hash.get_hash(content)
         self.assertEqual(self.hash, content_hash)
 
     def test_different_annotations_02(self):
+        """test_different_annotations_02"""
+
         # Make sure that an XSD with different comments produces the same hash
         with open(
-            join(RESOURCES_PATH, "chemical-element-annot-02.xsd"), "r", encoding="utf-8"
+            join(RESOURCES_PATH, "chemical-element-annot-02.xsd"),
+            "r",
+            encoding="utf-8",
         ) as xsd_file:
             content = xsd_file.read()
             content_hash = xsd_hash.get_hash(content)
         self.assertEqual(self.hash, content_hash)
 
     def test_different_namespace(self):
+        """test_different_namespace"""
+
         # Make sure that an XSD with different comments produces the same hash
         with open(
             join(RESOURCES_PATH, "chemical-element-namespace.xsd"),
@@ -92,10 +115,14 @@ class TestSimpleXSD(TestCase):
         self.assertNotEqual(self.hash, content_hash)
 
     def test_wrong_enum(self):
+        """test_wrong_enum"""
+
         # Make sure that an XSD with different enumeration does not produce
         # the same hash
         with open(
-            join(RESOURCES_PATH, "chemical-element-enum.xsd"), "r", encoding="utf-8"
+            join(RESOURCES_PATH, "chemical-element-enum.xsd"),
+            "r",
+            encoding="utf-8",
         ) as xsd_file:
             content = xsd_file.read()
             content_hash = xsd_hash.get_hash(content)
@@ -103,7 +130,11 @@ class TestSimpleXSD(TestCase):
 
 
 class TestCommonXSD(TestCase):
+    """Test Common XSD"""
+
     def setUp(self):
+        """setUp"""
+
         with open(
             join(RESOURCES_PATH, "composition.xsd"), "r", encoding="utf-8"
         ) as xsd_file:
@@ -111,6 +142,8 @@ class TestCommonXSD(TestCase):
             self.hash = xsd_hash.get_hash(self.content)
 
     def test_same_file(self):
+        """test_same_file"""
+
         # Make sure that the same XSD produces the same hash
         with open(
             join(RESOURCES_PATH, "composition.xsd"), "r", encoding="utf-8"
@@ -120,30 +153,42 @@ class TestCommonXSD(TestCase):
         self.assertEqual(self.hash, content_hash)
 
     def test_mixed_order(self):
+        """test_mixed_order"""
+
         # Make sure that an XSD with elements in a different order produces
         # the same hash
         with open(
-            join(RESOURCES_PATH, "composition-mixed.xsd"), "r", encoding="utf-8"
+            join(RESOURCES_PATH, "composition-mixed.xsd"),
+            "r",
+            encoding="utf-8",
         ) as xsd_file:
             content = xsd_file.read()
             content_hash = xsd_hash.get_hash(content)
         self.assertEqual(self.hash, content_hash)
 
     def test_different_root(self):
+        """test_different_root"""
+
         # Make sure that an XSD with different root names does not produce
         # the same hash
         with open(
-            join(RESOURCES_PATH, "composition-root-name.xsd"), "r", encoding="utf-8"
+            join(RESOURCES_PATH, "composition-root-name.xsd"),
+            "r",
+            encoding="utf-8",
         ) as xsd_file:
             content = xsd_file.read()
             content_hash = xsd_hash.get_hash(content)
         self.assertNotEqual(self.hash, content_hash)
 
     def test_different_type(self):
+        """test_different_type"""
+
         # Make sure that an XSD with different type names does not produce
         # the same hash
         with open(
-            join(RESOURCES_PATH, "composition-type-name.xsd"), "r", encoding="utf-8"
+            join(RESOURCES_PATH, "composition-type-name.xsd"),
+            "r",
+            encoding="utf-8",
         ) as xsd_file:
             content = xsd_file.read()
             content_hash = xsd_hash.get_hash(content)
@@ -151,7 +196,11 @@ class TestCommonXSD(TestCase):
 
 
 class TestComplexXSD(TestCase):
+    """Test Complex XSD"""
+
     def setUp(self):
+        """setUp"""
+
         with open(
             join(RESOURCES_PATH, "diffusion.xsd"), "r", encoding="utf-8"
         ) as xsd_file:
@@ -159,6 +208,8 @@ class TestComplexXSD(TestCase):
             self.hash = xsd_hash.get_hash(self.content)
 
     def test_same(self):
+        """test_same"""
+
         # Make sure that the same XSD produces the same hash
         with open(
             join(RESOURCES_PATH, "diffusion.xsd"), "r", encoding="utf-8"
@@ -168,6 +219,8 @@ class TestComplexXSD(TestCase):
         self.assertEqual(self.hash, content_hash)
 
     def test_mixed_order(self):
+        """test_mixed_order"""
+
         # Make sure that an XSD with elements in a different order produces
         # the same hash
         with open(
@@ -179,7 +232,11 @@ class TestComplexXSD(TestCase):
 
 
 class TestKnownXSD(TestCase):
+    """Test Known XSD"""
+
     def test_registry_hash_value(self):
+        """test_registry_hash_value"""
+
         res_md_hash = "4735069b4332ee196e95b4db7877b6dcea9692ec"
 
         with open(
@@ -190,6 +247,8 @@ class TestKnownXSD(TestCase):
         self.assertEqual(res_md_hash, content_hash)
 
     def test_ammd_hash_value(self):
+        """test_ammd_hash_value"""
+
         ammd_hash = "b056869f2e87adbf6b56b0ec19e65f9761cc6826"
 
         with open(
