@@ -1,5 +1,6 @@
 """ Unit tests for appinfo operations
 """
+
 from unittest import TestCase
 
 from lxml import etree
@@ -13,12 +14,18 @@ from xml_utils.xsd_tree.xsd_tree import XSDTree
 
 
 class TestAddAppInfoElement(TestCase):
-    def test_add_appinfo_element_invalid_xsd_raises_xsd_error(self):
+    """Test Add App Info Element"""
+
+    def test_add_app_info_element_invalid_xsd_raises_xsd_error(self):
+        """test_add_app_info_element_invalid_xsd_raises_xsd_error"""
+
         xsd_string = "invalid"
         with self.assertRaises(etree.XMLSyntaxError):
             add_appinfo_element(xsd_string, "", "", "")
 
-    def test_add_appinfo_element_invalid_xpath_raises_xsd_error(self):
+    def test_add_app_info_element_invalid_xpath_raises_xsd_error(self):
+        """test_add_app_info_element_invalid_xpath_raises_xsd_error"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <root><test></test></root>
@@ -28,7 +35,9 @@ class TestAddAppInfoElement(TestCase):
         with self.assertRaises(XMLError):
             add_appinfo_element(xsd_string, xpath, "attribute", "value")
 
-    def test_add_appinfo_element_no_annotation_adds_it(self):
+    def test_add_app_info_element_no_annotation_adds_it(self):
+        """test_add_app_info_element_no_annotation_adds_it"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root"/>
@@ -58,7 +67,9 @@ class TestAddAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_no_appinfo_adds_it(self):
+    def test_add_app_info_element_no_app_info_adds_it(self):
+        """test_add_app_info_element_no_app_info_adds_it"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -90,7 +101,9 @@ class TestAddAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_no_element_adds_it(self):
+    def test_add_app_info_element_no_element_adds_it(self):
+        """test_add_app_info_element_no_element_adds_it"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
             <xs:element name="root"><xs:annotation>
@@ -121,7 +134,9 @@ class TestAddAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_annotation_present_updates_it(self):
+    def test_add_app_info_element_annotation_present_updates_it(self):
+        """test_add_app_info_element_annotation_present_updates_it"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -153,7 +168,9 @@ class TestAddAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_appinfo_present_updates_it(self):
+    def test_add_app_info_element_app_info_present_updates_it(self):
+        """test_add_app_info_element_app_info_present_updates_it"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -185,7 +202,9 @@ class TestAddAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_present_updates_it(self):
+    def test_add_app_info_element_present_updates_it(self):
+        """test_add_app_info_element_present_updates_it"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -197,7 +216,9 @@ class TestAddAppInfoElement(TestCase):
         """
         xpath = "xs:element"
 
-        updated_xsd_string = add_appinfo_element(xsd_string, xpath, "attribute", "new")
+        updated_xsd_string = add_appinfo_element(
+            xsd_string, xpath, "attribute", "new"
+        )
 
         expected_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
@@ -217,7 +238,9 @@ class TestAddAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_absent_from_two_appinfo(self):
+    def test_add_app_info_element_absent_from_two_app_info(self):
+        """test_add_app_info_element_absent_from_two_appinfo"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -230,7 +253,9 @@ class TestAddAppInfoElement(TestCase):
         """
 
         xpath = "xs:element"
-        updated_xsd_string = add_appinfo_element(xsd_string, xpath, "attribute", "new")
+        updated_xsd_string = add_appinfo_element(
+            xsd_string, xpath, "attribute", "new"
+        )
 
         expected_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
@@ -251,7 +276,9 @@ class TestAddAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_present_in_first_of_two_appinfo(self):
+    def test_add_app_info_element_present_in_first_of_two_app_info(self):
+        """test_add_app_info_element_present_in_first_of_two_app_info"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -264,7 +291,9 @@ class TestAddAppInfoElement(TestCase):
         """
         xpath = "xs:element"
 
-        updated_xsd_string = add_appinfo_element(xsd_string, xpath, "attribute", "new")
+        updated_xsd_string = add_appinfo_element(
+            xsd_string, xpath, "attribute", "new"
+        )
 
         expected_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
@@ -285,7 +314,9 @@ class TestAddAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_present_in_second_of_two_appinfo(self):
+    def test_add_app_info_element_present_in_second_of_two_app_info(self):
+        """test_add_app_info_element_present_in_second_of_two_app_info"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -298,7 +329,9 @@ class TestAddAppInfoElement(TestCase):
         """
         xpath = "xs:element"
 
-        updated_xsd_string = add_appinfo_element(xsd_string, xpath, "attribute", "new")
+        updated_xsd_string = add_appinfo_element(
+            xsd_string, xpath, "attribute", "new"
+        )
 
         expected_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
@@ -319,7 +352,11 @@ class TestAddAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_present_in_two_appinfo_raises_exception(self):
+    def test_add_app_info_element_present_in_two_app_info_raises_exception(
+        self,
+    ):
+        """test_add_app_info_element_present_in_two_app_info_raises_exception"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -337,12 +374,18 @@ class TestAddAppInfoElement(TestCase):
 
 
 class TestDeleteAppInfoElement(TestCase):
-    def test_delete_appinfo_element_invalid_xsd_raises_xsd_error(self):
+    """Test Delete App Info Element"""
+
+    def test_delete_app_info_element_invalid_xsd_raises_xsd_error(self):
+        """test_delete_app_info_element_invalid_xsd_raises_xsd_error"""
+
         xsd_string = "invalid"
         with self.assertRaises(etree.XMLSyntaxError):
             delete_appinfo_element(xsd_string, "", "")
 
-    def test_delete_appinfo_element_invalid_xpath_raises_xsd_error(self):
+    def test_delete_app_info_element_invalid_xpath_raises_xsd_error(self):
+        """test_delete_app_info_element_invalid_xpath_raises_xsd_error"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <root><test></test></root>
@@ -352,7 +395,9 @@ class TestDeleteAppInfoElement(TestCase):
         with self.assertRaises(XMLError):
             delete_appinfo_element(xsd_string, xpath, "")
 
-    def test_delete_appinfo_element_removed_if_exists(self):
+    def test_delete_app_info_element_removed_if_exists(self):
+        """test_delete_app_info_element_removed_if_exists"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -364,7 +409,9 @@ class TestDeleteAppInfoElement(TestCase):
         """
         xpath = "xs:element"
         attribute_name = "attribute"
-        updated_xsd_string = delete_appinfo_element(xsd_string, xpath, attribute_name)
+        updated_xsd_string = delete_appinfo_element(
+            xsd_string, xpath, attribute_name
+        )
 
         expected_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
@@ -383,6 +430,8 @@ class TestDeleteAppInfoElement(TestCase):
         self.assertEqual(updated_xsd_string, expected_string)
 
     def test_delete_attribute_does_not_fail_if_not_present(self):
+        """test_delete_attribute_does_not_fail_if_not_present"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -394,7 +443,11 @@ class TestDeleteAppInfoElement(TestCase):
         attribute_name = "attribute"
         delete_appinfo_element(xsd_string, xpath, attribute_name)
 
-    def test_delete_appinfo_element_absent_from_two_appinfo_does_not_fail(self):
+    def test_delete_app_info_element_absent_from_two_appinfo_does_not_fail(
+        self,
+    ):
+        """test_delete_app_info_element_absent_from_two_appinfo_does_not_fail"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -409,7 +462,9 @@ class TestDeleteAppInfoElement(TestCase):
 
         delete_appinfo_element(xsd_string, xpath, "attribute")
 
-    def test_delete_appinfo_element_present_in_first_of_two_appinfo(self):
+    def test_delete_app_info_element_present_in_first_of_two_app_info(self):
+        """test_delete_app_info_element_present_in_first_of_two_appinfo"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -422,7 +477,9 @@ class TestDeleteAppInfoElement(TestCase):
         """
         xpath = "xs:element"
 
-        updated_xsd_string = delete_appinfo_element(xsd_string, xpath, "attribute")
+        updated_xsd_string = delete_appinfo_element(
+            xsd_string, xpath, "attribute"
+        )
 
         expected_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
@@ -442,7 +499,9 @@ class TestDeleteAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_present_in_second_of_two_appinfo(self):
+    def test_add_app_info_element_present_in_second_of_two_app_info(self):
+        """test_add_app_info_element_present_in_second_of_two_app_info"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
@@ -455,7 +514,9 @@ class TestDeleteAppInfoElement(TestCase):
         """
         xpath = "xs:element"
 
-        updated_xsd_string = delete_appinfo_element(xsd_string, xpath, "attribute")
+        updated_xsd_string = delete_appinfo_element(
+            xsd_string, xpath, "attribute"
+        )
 
         expected_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
@@ -473,7 +534,11 @@ class TestDeleteAppInfoElement(TestCase):
 
         self.assertEqual(updated_xsd_string, expected_string)
 
-    def test_add_appinfo_element_present_in_two_appinfo_raises_exception(self):
+    def test_add_app_info_element_present_in_two_app_info_raises_exception(
+        self,
+    ):
+        """test_add_app_info_element_present_in_two_app_info_raises_exception"""
+
         xsd_string = """
             <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
                 <xs:element name="root">
