@@ -1,5 +1,6 @@
 """Unit tests for xpath operations
 """
+
 from unittest import TestCase
 
 from xml_utils.commons.exceptions import XMLError
@@ -9,7 +10,11 @@ from xml_utils.xsd_tree.xsd_tree import XSDTree
 
 
 class TestGetElementByXpath(TestCase):
+    """Test Get Element By Xpath"""
+
     def test_get_element_xpath_matching_element(self):
+        """test_get_element_xpath_matching_element"""
+
         xsd_string = "<xs:schema xmlns:xs='http://www.w3.org/2001/XMLSchema'><root><test></test></root></xs:schema>"
         xpath = "root/test"
         xsd_tree = XSDTree.build_tree(xsd_string)
@@ -17,6 +22,8 @@ class TestGetElementByXpath(TestCase):
         self.assertTrue(element is not None)
 
     def test_get_element_xpath_matching_element_with_xs_namespace_prefix(self):
+        """test_get_element_xpath_matching_element_with_xs_namespace_prefix"""
+
         xsd_string = (
             "<xs:schema xmlns:xs='http://www.w3.org/2001/XMLSchema'><xs:element><xs:complexType>"
             "</xs:complexType></xs:element></xs:schema>"
@@ -27,7 +34,11 @@ class TestGetElementByXpath(TestCase):
         element = get_element_by_xpath(xsd_tree, xpath, namespaces)
         self.assertTrue(element is not None)
 
-    def test_get_element_xpath_matching_element_with_xsd_namespace_prefix(self):
+    def test_get_element_xpath_matching_element_with_xsd_namespace_prefix(
+        self,
+    ):
+        """test_get_element_xpath_matching_element_with_xsd_namespace_prefix"""
+
         xsd_string = (
             "<xsd:schema xmlns:xsd='http://www.w3.org/2001/XMLSchema'><xsd:element><xsd:complexType>"
             "</xsd:complexType></xsd:element></xsd:schema>"
@@ -41,6 +52,7 @@ class TestGetElementByXpath(TestCase):
     def test_get_element_xpath_not_matching_element_with_different_namespace_prefix(
         self,
     ):
+        """test_get_element_xpath_not_matching_element_with_different_namespace_prefix"""
         xsd_string = (
             "<xsd:schema xmlns:xsd='http://www.w3.org/2001/XMLSchema'><xsd:element><xsd:complexType>"
             "</xsd:complexType></xsd:element></xsd:schema>"
@@ -51,7 +63,11 @@ class TestGetElementByXpath(TestCase):
         with self.assertRaises(XMLError):
             get_element_by_xpath(xsd_tree, xpath, namespaces)
 
-    def test_get_element_xpath_not_matching_element_without_namespace_prefix(self):
+    def test_get_element_xpath_not_matching_element_without_namespace_prefix(
+        self,
+    ):
+        """test_get_element_xpath_not_matching_element_without_namespace_prefix"""
+
         xsd_string = (
             "<xsd:schema xmlns:xsd='http://www.w3.org/2001/XMLSchema'><xsd:element><xsd:complexType>"
             "</xsd:complexType></xsd:element></xsd:schema>"
@@ -63,6 +79,8 @@ class TestGetElementByXpath(TestCase):
             get_element_by_xpath(xsd_tree, xpath, namespaces)
 
     def test_get_element_xpath_not_matching_element(self):
+        """test_get_element_xpath_not_matching_element"""
+
         xsd_string = "<xs:schema xmlns:xs='http://www.w3.org/2001/XMLSchema'><root><test></test></root></xs:schema>"
         xpath = "root/name"
         xsd_tree = XSDTree.build_tree(xsd_string)
@@ -70,6 +88,8 @@ class TestGetElementByXpath(TestCase):
             get_element_by_xpath(xsd_tree, xpath)
 
     def test_get_element_invalid_xpath(self):
+        """test_get_element_invalid_xpath"""
+
         xsd_string = "<xs:schema xmlns:xs='http://www.w3.org/2001/XMLSchema'><root><test></test></root></xs:schema>"
         xpath = "invalid"
         xsd_tree = XSDTree.build_tree(xsd_string)
