@@ -1,5 +1,6 @@
 """ Package parsing HTML
 """
+
 from lxml import html
 from lxml.html.diff import htmldiff
 
@@ -19,9 +20,9 @@ def parse_html(html_text, parent_tag=""):
     Raises:
     """
     try:
-        return XSDTree.fromstring("<%s>%s</%s>" % (parent_tag, html_text, parent_tag))
-    except Exception as e:
-        raise HTMLError(str(e))
+        return XSDTree.fromstring(f"<{parent_tag}>{html_text}</{parent_tag}>")
+    except Exception as exception:
+        raise HTMLError(str(exception))
 
 
 def safe_html(html_text):
@@ -33,7 +34,8 @@ def safe_html(html_text):
     Returns:
     """
     return html.tostring(
-        html.fragment_fromstring(html_text, create_parent="div"), encoding="unicode"
+        html.fragment_fromstring(html_text, create_parent="div"),
+        encoding="unicode",
     )
 
 
