@@ -1,5 +1,6 @@
 """XSD Tree operations on annotations
 """
+
 from xml_utils.commons import constants as xml_utils_constants
 
 
@@ -14,7 +15,7 @@ def remove_annotations(xsd_tree):
     """
     # find all annotations
     annotations = xsd_tree.findall(
-        ".//{}annotation".format(xml_utils_constants.LXML_SCHEMA_NAMESPACE)
+        f".//{xml_utils_constants.LXML_SCHEMA_NAMESPACE}annotation"
     )
     for annotation in annotations:
         annotation.getparent().remove(annotation)
