@@ -1,5 +1,6 @@
 """XSD Tree operations on appinfo
 """
+
 from lxml import etree
 
 from xml_utils.commons import constants as xml_utils_constants
@@ -51,16 +52,16 @@ def _get_appinfo_element(element, element_name, namespace):
     """
     element_name_any_namespace = "{*}" + element_name
     appinfo_elements = element.findall(
-        "./{0}annotation/{0}appinfo/{1}".format(namespace, element_name_any_namespace)
+        f"./{namespace}annotation/{namespace}appinfo/{element_name_any_namespace}"
     )
 
     if len(appinfo_elements) == 1:
         return appinfo_elements[0]
-    elif len(appinfo_elements) > 1:
+    if len(appinfo_elements) > 1:
         raise XMLError(
-            "{} appinfo found multiple times in the same element".format(element_name)
+            f"{element_name} appinfo found multiple times in the same element"
         )
-    elif len(appinfo_elements) == 0:
+    if len(appinfo_elements) == 0:
         return None
 
 
@@ -162,10 +163,10 @@ def _get_or_create_element(parent, element_tag, namespace=""):
     Returns:
 
     """
-    element = parent.find("./{0}{1}".format(namespace, element_tag))
+    element = parent.find(f"./{namespace}{element_tag}")
     if element is None:
         # create element if absent
-        element = etree.Element("{0}{1}".format(namespace, element_tag))
+        element = etree.Element(f"{namespace}{element_tag}")
         # insert element
         parent.insert(0, element)
 
