@@ -1,5 +1,6 @@
 """XSD Tree operations on namespaces
 """
+
 from xml_utils.commons import constants as xml_utils_constants
 from xml_utils.xsd_tree.xsd_tree import XSDTree
 
@@ -21,7 +22,7 @@ def get_namespaces(xsd_string):
     for event, elem in XSDTree.iterparse(xsd_string, events):
         if event == "start-ns":
             if len(elem[0]) > 0 and len(elem[1]) > 0:
-                namespaces[elem[0]] = "%s" % elem[1]
+                namespaces[elem[0]] = f"{elem[1]}"
         elif event == "start":
             break
 
