@@ -1,5 +1,6 @@
 """XSD Tree operations on xpath
 """
+
 from xml_utils.commons import constants as xml_utils_constants
 from xml_utils.commons.exceptions import XMLError
 from xml_utils.xsd_tree.operations.namespaces import get_default_prefix
@@ -27,10 +28,10 @@ def get_element_by_xpath(xsd_tree, xpath, namespaces=None):
 
     try:
         element = xsd_tree.find(xpath)
-    except:
+    except Exception:
         raise XMLError("Unable to find an element for the given Xpath.")
 
-    if element is not None:
-        return element
-    else:
+    if element is None:
         raise XMLError("Unable to find an element for the given Xpath.")
+
+    return element
