@@ -1,15 +1,15 @@
 """ XSD tree operation, build, parse
 """
+
 from io import BytesIO
 
-import lxml.etree as etree
-from lxml.etree import Element, SubElement, XMLParser
+from lxml import etree
 
 import xml_utils.commons.constants as xml_constants
 import xml_utils.commons.exceptions as exceptions
 
 
-class XSDTree(object):
+class XSDTree:
     """XSD tree class"""
 
     @staticmethod
@@ -28,7 +28,7 @@ class XSDTree(object):
         except Exception:
             xml_string = BytesIO(xml_string)
         if not parser:
-            parser = XMLParser(remove_blank_text=True)
+            parser = etree.XMLParser(remove_blank_text=True)
         return etree.parse(xml_string, parser=parser)
 
     @staticmethod
@@ -43,9 +43,11 @@ class XSDTree(object):
 
         """
         try:
-            return etree.tostring(xml_tree, pretty_print=pretty, encoding="unicode")
-        except Exception as e:
-            raise exceptions.XMLError(str(e))
+            return etree.tostring(
+                xml_tree, pretty_print=pretty, encoding="unicode"
+            )
+        except Exception as exception:
+            raise exceptions.XMLError(str(exception))
 
     @staticmethod
     def transform_to_xslt(xml_parsed):
@@ -59,7 +61,7 @@ class XSDTree(object):
         """
         try:
             return etree.XSLT(xml_parsed)
-        except:
+        except Exception:
             return etree.XSLT(xml_parsed.encode("utf-8"))
 
     @staticmethod
@@ -74,10 +76,10 @@ class XSDTree(object):
 
         """
         if not parser:
-            parser = XMLParser(remove_blank_text=True)
+            parser = etree.XMLParser(remove_blank_text=True)
         try:
             return etree.XML(xml_string, parser=parser)
-        except:
+        except Exception:
             return etree.XML(xml_string.encode("utf-8"), parser=parser)
 
     @staticmethod
@@ -92,11 +94,11 @@ class XSDTree(object):
 
         """
         if not parser:
-            parser = XMLParser(remove_blank_text=True)
+            parser = etree.XMLParser(remove_blank_text=True)
         try:
             return etree.fromstring(xml_string, parser=parser)
-        except Exception as e:
-            raise exceptions.XMLError(str(e))
+        except Exception as exception:
+            raise exceptions.XMLError(str(exception))
 
     @staticmethod
     def iterfind(xml_string, match):
@@ -112,8 +114,8 @@ class XSDTree(object):
         try:
             xml_tree = XSDTree.build_tree(xml_string)
             return xml_tree.iterfind(match)
-        except Exception as e:
-            raise exceptions.XMLError(str(e))
+        except Exception as exception:
+            raise exceptions.XMLError(str(exception))
 
     @staticmethod
     def iterparse(xml_string, events):
@@ -127,13 +129,10 @@ class XSDTree(object):
 
         """
         try:
-            try:
-                xml_file = BytesIO(xml_string.encode("utf-8"))
-            except Exception:
-                xml_file = BytesIO(xml_string)
+            xml_file = BytesIO(xml_string.encode("utf-8"))
             return etree.iterparse(xml_file, events)
-        except Exception as e:
-            raise exceptions.XMLError(str(e))
+        except Exception as exception:
+            raise exceptions.XMLError(str(exception))
 
     @staticmethod
     def get_extension(xml_tree):
@@ -149,7 +148,7 @@ class XSDTree(object):
             return xml_tree.find(
                 "//xsl:output", namespaces={"xsl": xml_constants.XSL_NAMESPACE}
             ).attrib["method"]
-        except:
+        except Exception:
             # return default output format
             method = "xml"
             children = xml_tree.getroot().getchildren()
@@ -172,7 +171,7 @@ class XSDTree(object):
 
         Returns:
         """
-        return Element(tag, attrib, nsmap, **extra)
+        return etree.Element(tag, attrib, nsmap, **extra)
 
     @staticmethod
     def create_sub_element(parent, tag, attrib=None, nsmap=None, **extra):
@@ -188,4 +187,4 @@ class XSDTree(object):
 
         Returns:
         """
-        return SubElement(parent, tag, attrib, nsmap, **extra)
+        return etree.SubElement(parent, tag, attrib, nsmap, **extra)
